estimate_participant: Estimate the number of people needed and expected number of unique properties for a determined coverage based on the estimated norms
Description
Estimate the number of people needed and expected number of unique properties for a determined coverage based on the estimated norms
Usage
estimate_participant(est_norms, target_cover)
Value
A vector with the extra number of participant to achieve the specific coverage, and the estimate of the number of unique properties listed by the new amount of suggested people
Arguments
est_norms
A data frame with the estimated norms (generated by generateNorms function)
target_cover
Float between 0 and 1, corresponding to coverage (the fraction of the total incidence probabilities of the reported properties that are in the reference sample)